/***************************************************************************
 *   Copyright (C) 2009 by Rico Rommel   *
 *   rico@bierrommel.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "qstatesettings.h"
#include <QMessageBox>

QStateSettings::QStateSettings(QString text, QWidget * parent, QDBusInterface *interface)
 : QWidget(parent)
{
	state = new QLabel(text, this);
	TimeoutBox = new QSpinBox(this);
	BrightnessBox = new QSpinBox(this);
	name = text;
	TimeoutBox->setMinimum( -1 );
	BrightnessBox->setMaximum(100);

	idleinterface = interface;

	connect(TimeoutBox,SIGNAL(valueChanged ( int )), this, SLOT(TimeoutChanged( int )));



}


QStateSettings::~QStateSettings()
{
}


void QStateSettings::resizeEvent( QResizeEvent *event)
{
	int wx = event->size().width();
	int wy = event->size().height();

	int space = wy * 1 / 100;
	
	QFont font;
	float fsize = float(wy*30/100);
	font = state->font();
	font.setPointSize(fsize);

	state->setGeometry(0,space, wx * SETTINGSSTATEWIDTH / 100, wy);
	state->setFont(font);

	TimeoutBox->setGeometry(wx * SETTINGSSTATEWIDTH / 100 + space,space, wx*SETTINGSTIMEOUTWIDTH/100, wy);
	TimeoutBox->setFont(font);

	BrightnessBox->setGeometry(wx * (SETTINGSSTATEWIDTH +SETTINGSTIMEOUTWIDTH) / 100 + 2*space,space, wx*SETTINGSBRIGTHNESSWIDTH/100, wy);
	BrightnessBox->setFont(font);
	

}

/*!
    \fn QStateSettings::timeout()
 */
int QStateSettings::timeout()
{
    return TimeoutBox->value ();
}

void QStateSettings::setTimeout(int timeout)
{
    TimeoutBox->setValue( timeout );
}


/*!
    \fn QStateSettings::brightness()
 */
int QStateSettings::brightness()
{
    return BrightnessBox->value();
}


/*!
    \fn QStateSettings::setBrightness(int brightness)
 */
void QStateSettings::setBrightness(int brightness)
{
   BrightnessBox->setValue( brightness );
}


void QStateSettings::disableTimeout()
{
    TimeoutBox->hide();
}



void QStateSettings::disableBrightness()
{
    BrightnessBox->hide();
}



void QStateSettings::saveSettings(QSettings *settings)
{
    	settings->beginGroup(name);
	settings->setValue("timeout",timeout());
	settings->setValue("brightness",brightness());
	settings->endGroup();
}


void QStateSettings::loadSettings(QSettings *settings)
{
	settings->beginGroup(name);
	setTimeout (settings->value("timeout",5).toInt());
	setBrightness( settings->value("brightness",100).toInt() );
	settings->endGroup();

}



QString QStateSettings::getName()
{
   return name;
}


void QStateSettings::TimeoutChanged( int timeout )
{
    	idleinterface->call("SetTimeout", name, timeout);
	idleinterface->call("SetState", "busy");

}

/*!
    \fn QStateSettings::setTimeoutMinimum()
 */
void QStateSettings::setTimeoutMinimum( int min )
{
    TimeoutBox->setMinimum( min );
}


/*!
    \fn QStateSettings::setBrightnessMinimum( int min )
 */
void QStateSettings::setBrightnessMinimum( int min )
{
    BrightnessBox->setMinimum( min );
}
